==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/enums/AutomationRulePropertyArrayChangedConditionSupportedArrayType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class AutomationRulePropertyArrayChangedConditionSupportedArrayType(
    public val javaValue:
    com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType> {
    /**
     * Evaluate the condition on the alerts
     */
    Alerts(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Alerts),

    /**
     * Evaluate the condition on the labels
     */
    Labels(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Labels),

    /**
     * Evaluate the condition on the tactics
     */
    Tactics(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Tactics),

    /**
     * Evaluate the condition on the comments
     */
    Comments(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Comments),
    ;

    override fun toJava():
        com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType):
            AutomationRulePropertyArrayChangedConditionSupportedArrayType =
            AutomationRulePropertyArrayChangedConditionSupportedArrayType.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/enums/AutomationRulePropertyArrayChangedConditionSupportedArrayType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class AutomationRulePropertyArrayChangedConditionSupportedArrayType(
    public val javaValue: com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType> {
    /**
     * Evaluate the condition on the alerts
     */
    Alerts(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Alerts),

    /**
     * Evaluate the condition on the labels
     */
    Labels(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Labels),

    /**
     * Evaluate the condition on the tactics
     */
    Tactics(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Tactics),

    /**
     * Evaluate the condition on the comments
     */
    Comments(com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType.Comments),
    ;

    override fun toJava(): com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.securityinsights.enums.AutomationRulePropertyArrayChangedConditionSupportedArrayType): AutomationRulePropertyArrayChangedConditionSupportedArrayType =
            AutomationRulePropertyArrayChangedConditionSupportedArrayType.values().first { it.javaValue == javaType }
    }
}
